sample_ppm: Sample planted partition model

View source: R/sample_ppm.R

sample_ppmR Documentation

Sample planted partition model

Description

sample_ppm generates a random graph using the planted partition model, which is a special case of the stochastic block model.

Usage

sample_ppm(memb, p, q, seed = NULL)

Arguments

memb

Vector of community memberships.

p

Probability that vertices in same community are adjacent.

q

Probability that vertices in different communities are adjacent.

seed

Initial seed for edge randomisation (optional).

Details

See my blog post for more information.

Value

An igraph graph.


bldavies/bldr documentation built on March 29, 2024, 10:22 a.m.