| sample_ppm | R Documentation |
sample_ppm generates a random graph using the planted partition model,
which is a special case of the stochastic block model.
sample_ppm(memb, p, q, seed = NULL)
memb |
Vector of community memberships. |
p |
Probability that vertices in same community are adjacent. |
q |
Probability that vertices in different communities are adjacent. |
seed |
Initial seed for edge randomisation (optional). |
See my blog post for more information.
An igraph graph.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.